@@ -23,7 +23,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from copy import deepcopy
 
-from imdb.utils import analyze_title, build_title, normalizeTitle, \
+from imdb import articles
+from imdb.utils import analyze_title, build_title, canonicalTitle, \
                         flatten, _Container, cmpMovies
 
 
@@ -42,6 +43,7 @@ class Movie(_Container):
 
     # Aliases for some not-so-intuitive keys.
     keys_alias = {
+                'tv schedule': 'airing',
                 'user rating':  'rating',
                 'plot summary': 'plot',
                 'plot summaries': 'plot',
@@ -92,6 +94,8 @@ class Movie(_Container):
                 'aka':  'akas',
                 'also known as':    'akas',
                 'country':  'countries',
+                'production country':  'countries',
+                'production countries':  'countries',
                 'genre': 'genres',
                 'runtime':  'runtimes',
                 'lang': 'languages',
@@ -171,7 +175,7 @@ class Movie(_Container):
     def set_title(self, title):
         """Set the title of the movie."""
         # XXX: convert title to unicode, if it's a plain string?
-        d_title = analyze_title(title, canonical=1)
+        d_title = analyze_title(title)
         self.data.update(d_title)
 
     def _additional_keys(self):
@@ -179,39 +183,73 @@ class Movie(_Container):
         addkeys = []
         if self.data.has_key('title'):
             addkeys += ['canonical title', 'long imdb title',
-                        'long imdb canonical title']
+                        'long imdb canonical title',
+                        'smart canonical title',
+                        'smart long imdb canonical title']
         if self.data.has_key('episode of'):
             addkeys += ['long imdb episode title', 'series title',
                         'canonical series title', 'episode title',
-                        'canonical episode title']
+                        'canonical episode title',
+                        'smart canonical series title',
+                        'smart canonical episode title']
         return addkeys
 
+    def guessLanguage(self):
+        """Guess the language of the title of this movie; returns None
+        if there are no hints."""
+        lang = self.get('languages')
+        if lang:
+            lang = lang[0]
+        else:
+            country = self.get('countries')
+            if country:
+                lang = articles.COUNTRY_LANG.get(country[0])
+        return lang
+
+    def smartCanonicalTitle(self, title=None, lang=None):
+        """Return the canonical title, guessing its language.
+        The title can be forces with the 'title' argument (internally
+        used) and the language can be forced with the 'lang' argument,
+        otherwise it's auto-detected."""
+        if title is None:
+            title = self.data.get('title', u'')
+        if lang is None:
+            lang = self.guessLanguage()
+        return canonicalTitle(title, lang=lang)
+
     def _getitem(self, key):
         """Handle special keys."""
         if self.data.has_key('episode of'):
             if key == 'long imdb episode title':
-                return build_title(self.data, canonical=0)
+                return build_title(self.data)
             elif key == 'series title':
-                ser_title = self.data['episode of'].get('canonical title') or \
-                            self.data['episode of']['title']
-                return normalizeTitle(ser_title)
+                return self.data['episode of']['title']
             elif key == 'canonical series title':
-                ser_title = self.data['episode of'].get('canonical title') or \
-                            self.data['episode of']['title']
-                return ser_title
+                ser_title = self.data['episode of']['title']
+                return canonicalTitle(ser_title)
+            elif key == 'smart canonical series title':
+                ser_title = self.data['episode of']['title']
+                return self.smartCanonicalTitle(ser_title)
             elif key == 'episode title':
-                return normalizeTitle(self.data.get('title', u''))
-            elif key == 'canonical episode title':
                 return self.data.get('title', u'')
+            elif key == 'canonical episode title':
+                return canonicalTitle(self.data.get('title', u''))
+            elif key == 'smart canonical episode title':
+                return self.smartCanonicalTitle(self.data.get('title', u''))
         if self.data.has_key('title'):
             if key == 'title':
-                return normalizeTitle(self.data['title'])
-            elif key == 'long imdb title':
-                return build_title(self.data, canonical=0)
-            elif key == 'canonical title':
                 return self.data['title']
+            elif key == 'long imdb title':
+                return build_title(self.data)
+            elif key == 'canonical title':
+                return canonicalTitle(self.data['title'])
+            elif key == 'smart canonical title':
+                return self.smartCanonicalTitle(self.data['title'])
             elif key == 'long imdb canonical title':
                 return build_title(self.data, canonical=1)
+            elif key == 'smart long imdb canonical title':
+                return build_title(self.data, canonical=1,
+                                    lang=self.guessLanguage())
         return None
 
     def getID(self):
@@ -232,8 +270,8 @@ class Movie(_Container):
         if not isinstance(other, self.__class__): return 0
         if self.data.has_key('title') and \
                 other.data.has_key('title') and \
-                build_title(self.data, canonical=1) == \
-                build_title(other.data, canonical=1):
+                build_title(self.data, canonical=0) == \
+                build_title(other.data, canonical=0):
             return 1
         if self.accessSystem == other.accessSystem and \
                 self.movieID is not None and self.movieID == other.movieID:
@@ -284,7 +322,7 @@ class Movie(_Container):
         if self.has_key('long imdb episode title'):
             title = self.get('long imdb episode title')
         else:
-            title = self.get('long imdb canonical title')
+            title = self.get('long imdb title')
         r = '<Movie id:%s[%s] title:_%s_>' % (self.movieID, self.accessSystem,
                                                 title)
         if isinstance(r, unicode): r = r.encode('utf_8', 'replace')
