@@ -6,7 +6,7 @@ a person from the IMDb database.
 It can fetch data through different media (e.g.: the IMDb web pages,
 a SQL database, etc.)
 
-Copyright 2004-2009 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2010 Davide Alberani <da@erlug.linux.it>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,15 +25,16 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 __all__ = ['IMDb', 'IMDbError', 'Movie', 'Person', 'Character', 'Company',
             'available_access_systems']
-__version__ = VERSION = '4.3svn20091117'
+__version__ = VERSION = '4.4'
 
 # Import compatibility module (importing it is enough).
 import _compat
 
-import sys, os, ConfigParser
+import sys, os, ConfigParser, logging
 from types import MethodType
 
 from imdb import Movie, Person, Character, Company
+import imdb._logging
 from imdb._exceptions import IMDbError, IMDbDataAccessError
 from imdb.utils import build_title, build_name, build_company_name
 
@@ -162,6 +163,18 @@ def IMDb(accessSystem=None, *arguments, **keywords):
             # wrong: ignore everything and pretend we were called with
             # the 'http' accessSystem.
             accessSystem = 'http'
+    if 'loggingLevel' in keywords:
+        imdb._logging.setLevel(keywords['loggingLevel'])
+        del keywords['loggingLevel']
+    if 'loggingConfig' in keywords:
+        logCfg = keywords['loggingConfig']
+        del keywords['loggingConfig']
+        try:
+            import logging.config
+            logging.config.fileConfig(os.path.expanduser(logCfg))
+        except Exception, e:
+            import warnings
+            warnings.warn('unable to read logger config: %s' % e)
     if accessSystem in ('http', 'web', 'html'):
         from parser.http import IMDbHTTPAccessSystem
         return IMDbHTTPAccessSystem(*arguments, **keywords)
@@ -226,6 +239,9 @@ class IMDbBase:
     # in the subclasses).
     accessSystem = 'UNKNOWN'
 
+    # Top-level logger for IMDbPY.
+    _imdb_logger = logging.getLogger('imdbpy')
+
     def __init__(self, defaultModFunct=None, results=20, keywordsResults=100,
                 *arguments, **keywords):
         """Initialize the access system.
@@ -694,7 +710,14 @@ class IMDbBase:
                                     (prefix, i.replace(' ', '_')))
             except AttributeError:
                 raise IMDbDataAccessError, 'unknown information set "%s"' % i
-            ret = method(mopID)
+            try:
+                ret = method(mopID)
+            except Exception, e:
+                self._imdb_logger.critical('caught an exception retrieving ' \
+                                    'or parsing "%s" info set for mopID ' \
+                                    '"%s" (accessSystem: %s)',
+                                    i, mopID, mop.accessSystem, exc_info=True)
+                ret = {}
             keys = None
             if 'data' in ret:
                 res.update(ret['data'])
@@ -703,8 +726,6 @@ class IMDbBase:
             if 'info sets' in ret:
                 for ri in ret['info sets']:
                     mop.add_to_current_info(ri, keys, mainInfoset=i)
-                # So that only the 'main' required info set is set.
-                #mop.update_infoset_map(i, keys)
             else:
                 mop.add_to_current_info(i, keys)
             if 'titlesRefs' in ret:
