@@ -27,11 +27,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
 import re
-from imdb import imdbURL_base
-from imdb.utils import analyze_title, analyze_name, analyze_company_name, \
-                        build_title
+from imdb.utils import analyze_title, build_title
 from utils import DOMParserBase, Attribute, Extractor, analyze_imdbid
-from imdb.Movie import Movie
 
 
 class DOMBasicMovieParser(DOMParserBase):
@@ -42,8 +39,8 @@ class DOMBasicMovieParser(DOMParserBase):
     movie, the web server sends directly the movie page."""
     # Stay generic enough to be used also for other DOMBasic*Parser classes.
     _titleAttrPath = ".//text()"
-    _linkPath = "//a[starts-with(@href, '/title/tt')]"
-    _titleFunct = lambda self, x: analyze_title(x or u'', canonical=1)
+    _linkPath = "//link[@rel='canonical']"
+    _titleFunct = lambda self, x: analyze_title(x or u'')
 
     def _init(self):
         self.preprocessors += [('<span class="tv-extra">TV mini-series</span>',
@@ -85,7 +82,7 @@ def custom_analyze_title(title):
         title = nt
     if not title:
         return {}
-    return analyze_title(title, canonical=1)
+    return analyze_title(title)
 
 # Manage AKAs.
 _reAKAStitles = re.compile(r'(?:aka) <em>"(.*?)(<br>|<\/td>)', re.I | re.M)
@@ -96,7 +93,7 @@ class DOMHTMLSearchMovieParser(DOMParserBase):
 
     _BaseParser = DOMBasicMovieParser
     _notDirectHitTitle = '<title>imdb title'
-    _titleBuilder = lambda self, x: build_title(x, canonical=True)
+    _titleBuilder = lambda self, x: build_title(x)
     _linkPrefix = '/title/tt'
 
     _attrs = [Attribute(key='data',
