@@ -89,8 +89,8 @@ def _buildFakeFKTable(cls, fakeTableName):
         else:
             foreignColName = 'id'
         # Unused...
-        fkName = 'fk_%s_%s_%d' % (foreignTableName, foreignColName,
-                                countCols)
+        #fkName = 'fk_%s_%s_%d' % (foreignTableName, foreignColName,
+        #                        countCols)
         # Create a Foreign Key column, with the correct references.
         fk = ForeignKey(foreignTableName, name=thisColName, default=None)
         attrs[thisColName] = fk
@@ -173,9 +173,10 @@ def setConnection(uri, tables, encoding='utf8', debug=False):
     # FIXME: it's absolutely unclear what we should do to correctly
     #        support unicode in MySQL; with some versions of SQLObject,
     #        it seems that setting use_unicode=1 is the _wrong_ thing to do.
-    if uri.lower().startswith('mysql'):
+    _uriLower = uri.lower()
+    if _uriLower.startswith('mysql'):
         kw['use_unicode'] = 1
-        kw['sqlobject_encoding'] = encoding
+        #kw['sqlobject_encoding'] = encoding
         kw['charset'] = encoding
     conn = connectionForURI(uri, **kw)
     conn.debug = debug
