@@ -43,7 +43,7 @@ re_index = re.compile(r'^\(([IVXLCDM]+)\)$')
 
 # Match the number of episodes.
 re_episodes = re.compile('\s?\((\d+) episodes\)', re.I)
-re_episode_info = re.compile(r'{(.+?)?\s?(\([0-9\?]{4}-[0-9\?]{1,2}-[0-9\?]{1,2}\))?\s?(\(#[0-9]+\.[0-9]+\))?}')
+re_episode_info = re.compile(r'{\s*(.+?)?\s?(\([0-9\?]{4}-[0-9\?]{1,2}-[0-9\?]{1,2}\))?\s?(\(#[0-9]+\.[0-9]+\))?}')
 
 # Common suffixes in surnames.
 _sname_suffixes = ('de', 'la', 'der', 'den', 'del', 'y', 'da', 'van',
@@ -251,7 +251,7 @@ def _split_series_episode(title):
         if begin_eps == -1: return '', ''
         series_title = title[:begin_eps].rstrip()
         # episode_or_year is returned with the {...}
-        episode_or_year = title[begin_eps:]
+        episode_or_year = title[begin_eps:].strip()
         if episode_or_year[:12] == '{SUSPENDED}}': return '', ''
     # XXX: works only with tv series; it's still unclear whether
     #      IMDb will support episodes for tv mini series and tv movies...
@@ -316,6 +316,7 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
             if match:
                 # Episode title, original air date and #season.episode
                 episode_or_year, oad, sen = match[0]
+                episode_or_year = episode_or_year.strip()
                 if not oad:
                     # No year, but the title is something like (2005-04-12)
                     if episode_or_year and episode_or_year[0] == '(' and \
@@ -774,7 +775,9 @@ class RolesList(list):
 
 
 # Replace & with &amp;, but only if it's not already part of a charref.
-_re_amp = re.compile(r'(&)(?!\w+;)', re.I)
+#_re_amp = re.compile(r'(&)(?!\w+;)', re.I)
+#_re_amp = re.compile(r'(?<=\W)&(?=[^a-zA-Z0-9_#])')
+_re_amp = re.compile(r'&(?![^a-zA-Z0-9_#]{1,5};)')
 
 def escape4xml(value):
     """Escape some chars that can't be present in a XML value."""
@@ -806,6 +809,11 @@ def _refsToReplace(value, modFunct, titlesRefs, namesRefs, charactersRefs):
             # modFunct is modified.
             goodValue = modFunct(refTemplate % theRef, titlesRefs, namesRefs,
                                 charactersRefs)
+            # Prevents problems with crap in plain text data files.
+            # We should probably exclude invalid chars and string that
+            # are too long in the re_*Ref expressions.
+            if '_' in goodValue or len(goodValue) > 128:
+                continue
             toReplace = escape4xml(goodValue)
             # Only the 'value' portion is replaced.
             replaceWith = goodValue.replace(theRef, escape4xml(theRef))
@@ -1015,7 +1023,8 @@ _xmlHead = u"""<?xml version="1.0"?>
 <!DOCTYPE %s SYSTEM "http://imdbpy.sf.net/dtd/imdbpy{VERSION}.dtd">
 
 """
-_xmlHead = _xmlHead.replace('{VERSION}', VERSION.replace('.', ''))
+_xmlHead = _xmlHead.replace('{VERSION}',
+            VERSION.replace('.', '').split('svn')[0])
 
 
 class _Container(object):
